@@ -2,7 +2,7 @@ test_that("can make simple batch request", {
   chat <- chat_claude("Be as terse as possible; no punctuation")
   resp <- chat$chat("What is 1 + 1?", echo = FALSE)
   expect_match(resp, "2")
-  expect_equal(chat$last_turn()@tokens, c(26, 5))
+  expect_equal(chat$last_turn()@tokens > 0, c(TRUE, TRUE))
 })
 
 test_that("can make simple streaming request", {
@@ -27,15 +27,11 @@ test_that("respects turns interface", {
 test_that("all tool variations work", {
   chat_fun <- chat_claude
 
-  test_tools_simple(chat_fun)
+  retry_test(test_tools_simple(chat_fun))
   test_tools_async(chat_fun)
   test_tools_parallel(chat_fun)
-
-  # Fails occassionally returning "" instead of Susan
-  retry_test(
-    test_tools_sequential(chat_fun, total_calls = 6),
-    retries = 2
-  )
+  # Claude sometimes returns an empty string
+  retry_test(test_tools_sequential(chat_fun, total_calls = 6))
 })
 
 test_that("can extract data", {
@@ -50,3 +46,9 @@ test_that("can use images", {
   test_images_inline(chat_fun)
   test_images_remote_error(chat_fun)
 })
+
+test_that("can use pdfs", {
+  chat_fun <- chat_claude
+
+  test_pdf_local(chat_fun)
+})
